@@ -83,6 +83,7 @@ class CTM(AbstractModel):
             hyperparameters = {}
 
         self.set_params(hyperparameters)
+        self.vocab = dataset.get_vocabulary()
 
         if self.use_partitions:
             train, validation, test = dataset.get_partitioned_corpus(use_validation=True)
@@ -91,13 +92,30 @@ class CTM(AbstractModel):
             data_corpus_test = [' '.join(i) for i in test]
             data_corpus_validation = [' '.join(i) for i in validation]
 
-            self.vocab = dataset.get_vocabulary()
             x_train, x_test, x_valid, input_size = self.preprocess(
                 self.vocab, data_corpus_train, test=data_corpus_test, validation=data_corpus_validation,
                 bert_train_path=self.hyperparameters['bert_path'] + "_train.pkl",
                 bert_test_path=self.hyperparameters['bert_path'] + "_test.pkl",
                 bert_val_path=self.hyperparameters['bert_path'] + "_val.pkl",
                 bert_model=self.hyperparameters["bert_model"])
+            self.model = ctm.CTM(input_size=input_size, bert_input_size=x_train.X_bert.shape[1], model_type='prodLDA',
+                                 num_topics=self.hyperparameters['num_topics'], dropout=self.hyperparameters['dropout'],
+                                 activation=self.hyperparameters['activation'], lr=self.hyperparameters['lr'],
+                                 inference_type=self.hyperparameters['inference_type'],
+                                 hidden_sizes=self.hyperparameters['hidden_sizes'],
+                                 solver=self.hyperparameters['solver'],
+                                 momentum=self.hyperparameters['momentum'],
+                                 num_epochs=self.hyperparameters['num_epochs'],
+                                 learn_priors=self.hyperparameters['learn_priors'],
+                                 batch_size=self.hyperparameters['batch_size'],
+                                 num_samples=self.hyperparameters['num_samples'],
+                                 topic_prior_mean=self.hyperparameters["prior_mean"],
+                                 reduce_on_plateau=self.hyperparameters['reduce_on_plateau'],
+                                 topic_prior_variance=self.hyperparameters["prior_variance"])
+            self.model.fit(x_train, x_valid, verbose=False)
+            result = self.inference(x_test)
+            return result
+
         else:
             data_corpus = [' '.join(i) for i in dataset.get_corpus()]
             x_train, input_size = self.preprocess(
@@ -117,12 +135,9 @@ class CTM(AbstractModel):
                              reduce_on_plateau=self.hyperparameters['reduce_on_plateau'],
                              topic_prior_variance=self.hyperparameters["prior_variance"])
 
-        self.model.fit(x_train, x_valid, verbose=False)
 
-        if self.use_partitions:
-            result = self.inference(x_test)
-        else:
-            result = self.model.get_info()
+        self.model.fit(x_train, None, verbose=False)
+        result = self.model.get_info()
         return result
 
     def set_params(self, hyperparameters):
@@ -146,7 +161,7 @@ class CTM(AbstractModel):
                    bert_train_path=None, bert_test_path=None, bert_val_path=None):
         vocab2id = {w: i for i, w in enumerate(vocab)}
         vec = CountVectorizer(
-            vocabulary=vocab2id, token_pattern=r'(?u)\b\w+\b')
+            vocabulary=vocab2id, token_pattern=r'(?u)\b[\w+|\-]+\b')
         entire_dataset = train.copy()
         if test is not None:
             entire_dataset.extend(test)
